==> scanning-sdk-0.6.0-sources.jar: com/estimote/scanning_sdk/packet_provider/EstimotePacketProvider.kt <==
package com.estimote.scanning_sdk.packet_provider

import android.annotation.TargetApi
import android.os.Build
import com.estimote.internal_plugins_api.scanning.*
import com.estimote.scanning_sdk.packet_provider.use_cases.*
import com.estimote.scanning_sdk.settings.*
import io.reactivex.Observable

/**
 * @author Pawel Dylag (pawel.dylag@estimote.com)
 */
internal class EstimotePacketProvider(private val iBeaconScanUseCase: IBeaconScanUseCase,
                             private val eddystoneUidScanUseCase: EddystoneUidScanUseCase,
                             private val estimoteLocationScanUseCase: EstimoteLocationScanUseCase,
                             private val estimoteMeshScanUseCase: EstimoteMeshScanUseCase,
                             private val estimoteConnectivityScanUseCase: EstimoteConnectivityScanUseCase,
                             private val estimoteNearableScanUseCase: EstimoteNearableScanUseCase,
                             private val estimoteUwbScanUseCase: EstimoteUwbScanUseCase) : PacketProvider {

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideIBeacon(scanSettings: IBeaconScanSettings): Observable<out Beacon> {
        return iBeaconScanUseCase.run(scanSettings)
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEddystoneUid(scanSettings: EddystoneScanSettings): Observable<out EddystoneUid> {
        return eddystoneUidScanUseCase.run(scanSettings)
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteLocation(scanSettings: EstimoteLocationScanSettings): Observable<out EstimoteLocation> {
        return estimoteLocationScanUseCase.run(scanSettings).map { it as EstimoteLocation }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteMesh(scanSettings: EstimoteMeshScanSettings): Observable<out EstimoteMesh> {
        return estimoteMeshScanUseCase.run(scanSettings).map { it as EstimoteMesh }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideConnectivity(scanSettings: ConnectivityScanSettings): Observable<out EstimoteConnectivity> {
        return estimoteConnectivityScanUseCase.run(scanSettings).map { it as EstimoteConnectivity }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideNearable(scanSettings: NearableScanSettings): Observable<out EstimoteNearable> {
        return estimoteNearableScanUseCase.run(scanSettings).map { it as EstimoteNearable }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteUwb(scanSettings: UwbScanSettings): Observable<out EstimoteUwb> {
        return estimoteUwbScanUseCase.run(scanSettings).map { it as EstimoteUwb }
    }
}

==> scanning-sdk-0.8.0-sources.jar: com/estimote/scanning_sdk/packet_provider/EstimotePacketProvider.kt <==
package com.estimote.scanning_sdk.packet_provider

import android.annotation.TargetApi
import android.os.Build
import com.estimote.internal_plugins_api.scanning.*
import com.estimote.scanning_sdk.packet_provider.use_cases.*
import com.estimote.scanning_sdk.settings.*
import io.reactivex.Observable

/**
 * @author Pawel Dylag (pawel.dylag@estimote.com)
 */
internal class EstimotePacketProvider(private val iBeaconScanUseCase: IBeaconScanUseCase,
                             private val eddystoneUidScanUseCase: EddystoneUidScanUseCase,
                             private val estimoteLocationScanUseCase: EstimoteLocationScanUseCase,
                             private val estimoteMeshScanUseCase: EstimoteMeshScanUseCase,
                             private val estimoteConnectivityScanUseCase: EstimoteConnectivityScanUseCase,
                             private val estimoteNearableScanUseCase: EstimoteNearableScanUseCase,
                             private val estimoteUwbScanUseCase: EstimoteUwbScanUseCase,
                             private val estimoteMirrorScanUseCase: EstimoteMirrorScanUseCase) : PacketProvider {

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideIBeacon(scanSettings: IBeaconScanSettings): Observable<out Beacon> {
        return iBeaconScanUseCase.run(scanSettings)
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEddystoneUid(scanSettings: EddystoneScanSettings): Observable<out EddystoneUid> {
        return eddystoneUidScanUseCase.run(scanSettings)
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteLocation(scanSettings: EstimoteLocationScanSettings): Observable<out EstimoteLocation> {
        return estimoteLocationScanUseCase.run(scanSettings).map { it as EstimoteLocation }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteMesh(scanSettings: EstimoteMeshScanSettings): Observable<out EstimoteMesh> {
        return estimoteMeshScanUseCase.run(scanSettings).map { it as EstimoteMesh }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideConnectivity(scanSettings: ConnectivityScanSettings): Observable<out EstimoteConnectivity> {
        return estimoteConnectivityScanUseCase.run(scanSettings).map { it as EstimoteConnectivity }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideNearable(scanSettings: NearableScanSettings): Observable<out EstimoteNearable> {
        return estimoteNearableScanUseCase.run(scanSettings).map { it as EstimoteNearable }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteUwb(scanSettings: UwbScanSettings): Observable<out EstimoteUwb> {
        return estimoteUwbScanUseCase.run(scanSettings).map { it as EstimoteUwb }
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    override fun provideEstimoteMirror(scanSettings: MirrorScanSettings): Observable<out EstimoteMirror> {
        return estimoteMirrorScanUseCase.run(scanSettings).map { it as EstimoteMirror }
    }
}
